==> rucio-0.2.13.tar.gz: rucio-0.2.13/lib/rucio/db/migrate_repo/versions/384b96aa0f60_created_rule_history_tables.py <==
# Copyright European Organization for Nuclear Research (CERN)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# You may not use this file except in compliance with the License.
# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Authors:
# - Martin Barisits, <martin.barisits@cern.ch>, 2015

"""Created rule history tables

Revision ID: 384b96aa0f60
Revises: 271a46ea6244
Create Date: 2015-01-21 15:30:23.689422

"""

# revision identifiers, used by Alembic.
revision = '384b96aa0f60'
down_revision = '4cf0a2e127d4'

from alembic import op, context
import sqlalchemy as sa

from rucio.db.constants import (DIDType, RuleGrouping, RuleState, RuleNotification)
from rucio.db.types import GUID


def upgrade():
    op.create_table('rules_hist_recent',
                    sa.Column('history_id', GUID()),
                    sa.Column('id', GUID()),
                    sa.Column('subscription_id', GUID()),
                    sa.Column('account', sa.String(25)),
                    sa.Column('scope', sa.String(25)),
                    sa.Column('name', sa.String(255)),
                    sa.Column('did_type', DIDType.db_type()),
                    sa.Column('state', RuleState.db_type()),
                    sa.Column('error', sa.String(255)),
                    sa.Column('rse_expression', sa.String(255)),
                    sa.Column('copies', sa.SmallInteger),
                    sa.Column('expires_at', sa.DateTime),
                    sa.Column('weight', sa.String(255)),
                    sa.Column('locked', sa.Boolean()),
                    sa.Column('locks_ok_cnt', sa.BigInteger),
                    sa.Column('locks_replicating_cnt', sa.BigInteger),
                    sa.Column('locks_stuck_cnt', sa.BigInteger),
                    sa.Column('source_replica_expression', sa.String(255)),
                    sa.Column('activity', sa.String(50)),
                    sa.Column('grouping', RuleGrouping.db_type()),
                    sa.Column('notification', RuleNotification.db_type()),
                    sa.Column('stuck_at', sa.DateTime),
                    sa.Column('purge_replicas', sa.Boolean()),
                    sa.Column('ignore_availability', sa.Boolean()),
                    sa.Column('updated_at', sa.DateTime),
                    sa.Column('created_at', sa.DateTime))
    op.create_table('rules_hist_longterm',
                    sa.Column('history_id', GUID()),
                    sa.Column('id', GUID()),
                    sa.Column('subscription_id', GUID()),
                    sa.Column('account', sa.String(25)),
                    sa.Column('scope', sa.String(25)),
                    sa.Column('name', sa.String(255)),
                    sa.Column('did_type', DIDType.db_type()),
                    sa.Column('state', RuleState.db_type()),
                    sa.Column('error', sa.String(255)),
                    sa.Column('rse_expression', sa.String(255)),
                    sa.Column('copies', sa.SmallInteger),
                    sa.Column('expires_at', sa.DateTime),
                    sa.Column('weight', sa.String(255)),
                    sa.Column('locked', sa.Boolean()),
                    sa.Column('locks_ok_cnt', sa.BigInteger),
                    sa.Column('locks_replicating_cnt', sa.BigInteger),
                    sa.Column('locks_stuck_cnt', sa.BigInteger),
                    sa.Column('source_replica_expression', sa.String(255)),
                    sa.Column('activity', sa.String(50)),
                    sa.Column('grouping', RuleGrouping.db_type()),
                    sa.Column('notification', RuleNotification.db_type()),
                    sa.Column('stuck_at', sa.DateTime),
                    sa.Column('purge_replicas', sa.Boolean()),
                    sa.Column('ignore_availability', sa.Boolean()),
                    sa.Column('updated_at', sa.DateTime),
                    sa.Column('created_at', sa.DateTime))
    if context.get_context().dialect.name != 'sqlite':
        op.create_index('RULES_HIST_RECENT_ID_IDX', 'rules_hist_recent', ["id"])


def downgrade():
    if context.get_context().dialect.name is 'postgresql':
        op.drop_index('RULES_HIST_RECENT_ID_IDX', 'rules_hist_recent')
    op.drop_table('rules_hist_recent')
    op.drop_table('rules_hist_longterm')

==> rucio-1.1.1.tar.gz: rucio-1.1.1/lib/rucio/db/migrate_repo/versions/384b96aa0f60_created_rule_history_tables.py <==
# Copyright European Organization for Nuclear Research (CERN)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# You may not use this file except in compliance with the License.
# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Authors:
# - Martin Barisits, <martin.barisits@cern.ch>, 2015

"""Created rule history tables

Revision ID: 384b96aa0f60
Revises: 271a46ea6244
Create Date: 2015-01-21 15:30:23.689422

"""

# revision identifiers, used by Alembic.
revision = '384b96aa0f60'
down_revision = '4cf0a2e127d4'

from alembic import op, context
import sqlalchemy as sa

from rucio.db.constants import (DIDType, RuleGrouping, RuleState, RuleNotification)
from rucio.db.types import GUID


def upgrade():
    op.create_table('rules_hist_recent',
                    sa.Column('history_id', GUID()),
                    sa.Column('id', GUID()),
                    sa.Column('subscription_id', GUID()),
                    sa.Column('account', sa.String(25)),
                    sa.Column('scope', sa.String(25)),
                    sa.Column('name', sa.String(255)),
                    sa.Column('did_type', DIDType.db_type()),
                    sa.Column('state', RuleState.db_type()),
                    sa.Column('error', sa.String(255)),
                    sa.Column('rse_expression', sa.String(255)),
                    sa.Column('copies', sa.SmallInteger),
                    sa.Column('expires_at', sa.DateTime),
                    sa.Column('weight', sa.String(255)),
                    sa.Column('locked', sa.Boolean()),
                    sa.Column('locks_ok_cnt', sa.BigInteger),
                    sa.Column('locks_replicating_cnt', sa.BigInteger),
                    sa.Column('locks_stuck_cnt', sa.BigInteger),
                    sa.Column('source_replica_expression', sa.String(255)),
                    sa.Column('activity', sa.String(50)),
                    sa.Column('grouping', RuleGrouping.db_type()),
                    sa.Column('notification', RuleNotification.db_type()),
                    sa.Column('stuck_at', sa.DateTime),
                    sa.Column('purge_replicas', sa.Boolean()),
                    sa.Column('ignore_availability', sa.Boolean()),
                    sa.Column('updated_at', sa.DateTime),
                    sa.Column('created_at', sa.DateTime))
    op.create_table('rules_history',
                    sa.Column('history_id', GUID()),
                    sa.Column('id', GUID()),
                    sa.Column('subscription_id', GUID()),
                    sa.Column('account', sa.String(25)),
                    sa.Column('scope', sa.String(25)),
                    sa.Column('name', sa.String(255)),
                    sa.Column('did_type', DIDType.db_type()),
                    sa.Column('state', RuleState.db_type()),
                    sa.Column('error', sa.String(255)),
                    sa.Column('rse_expression', sa.String(255)),
                    sa.Column('copies', sa.SmallInteger),
                    sa.Column('expires_at', sa.DateTime),
                    sa.Column('weight', sa.String(255)),
                    sa.Column('locked', sa.Boolean()),
                    sa.Column('locks_ok_cnt', sa.BigInteger),
                    sa.Column('locks_replicating_cnt', sa.BigInteger),
                    sa.Column('locks_stuck_cnt', sa.BigInteger),
                    sa.Column('source_replica_expression', sa.String(255)),
                    sa.Column('activity', sa.String(50)),
                    sa.Column('grouping', RuleGrouping.db_type()),
                    sa.Column('notification', RuleNotification.db_type()),
                    sa.Column('stuck_at', sa.DateTime),
                    sa.Column('purge_replicas', sa.Boolean()),
                    sa.Column('ignore_availability', sa.Boolean()),
                    sa.Column('updated_at', sa.DateTime),
                    sa.Column('created_at', sa.DateTime))
    if context.get_context().dialect.name != 'sqlite':
        op.create_index('RULES_HIST_RECENT_ID_IDX', 'rules_hist_recent', ["id"])


def downgrade():
    if context.get_context().dialect.name is 'postgresql':
        op.drop_index('RULES_HIST_RECENT_ID_IDX', 'rules_hist_recent')
    op.drop_table('rules_hist_recent')
    op.drop_table('rules_history')
